@@ -2,13 +2,13 @@ from granola import serve
 
 class Main:
     def main(self):
-        return "data"
+        return {"source": "main"}
 
 class App:
     def __granola__(self):
-        return "WELCOME TO SERVER"
+        return "<h1> Hello WOrld </h1>"
 
-    def api(self, request):
+    def api(self):
         return Main()
 
 serve(8685, App())
